@@ -6,7 +6,7 @@ no warnings qw(void once uninitialized numeric);
 package Moops;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008';
+our $VERSION   = '0.009';
 
 use Devel::Pragma qw(ccstash);
 use Exporter::TypeTiny qw(mkopt);
@@ -73,7 +73,7 @@ sub at_runtime
 {
 	my $class = shift;
 	my ($pkg) = @_;
-	for my $task (@{ $Moops::AT_RUNTIME })
+	for my $task (@{ $Moops::AT_RUNTIME{$pkg} })
 	{
 		my ($code, @args) = @$task;
 		eval "package $pkg; \$code->(\@args)";
@@ -299,13 +299,13 @@ should generally be usable by package-qualifying them:
 
    use MooseX::Types::Numeric qw();
    
-   method foo ( MooseX::Types::Numeric::SingleDigit $d ) {
+   method foo ( MooseX::Types::Common::Numeric::PositiveInt $d ) {
       # ...
    }
 
 Alternatively:
 
-   use MooseX::Types::Numeric qw(SingleDigit);
+   use MooseX::Types::Common::Numeric qw(PositiveInt);
    
    method foo ( (SingleDigit) $d ) {
       # ...
@@ -316,6 +316,10 @@ signature; this is required for Function::Parameters to realise
 that C<SingleDigit> is an imported symbol, and not a string to
 be looked up.
 
+(The version using the fully-qualified name should even work in
+L<Moo> and L<Mouse> classes, because it forces the type constraint
+to be loaded via (and wrapped by) Type::Tiny.)
+
 =head2 Constants
 
 The useful constants C<true> and C<false> are imported into all declared
